@@ -7,9 +7,7 @@
 			$this->output->keywords = "login";
 			$this->output->title = "Login";
 
-			$this->output->add_javascript("banshee/".PASSWORD_HASH.".js");
 			$this->output->add_javascript("banshee/login.js");
-			$this->output->run_javascript("set_focus(); hash = window['".PASSWORD_HASH."'];");
 
 			$this->output->open_tag("login");
 
@@ -25,7 +23,6 @@
 			}
 
 			$this->output->add_tag("remote_addr", $_SERVER["REMOTE_ADDR"]);
-			$this->output->add_tag("challenge", $_SESSION["challenge"]);
 
 			if ($_SERVER["REQUEST_METHOD"] == "POST") {
 				if (strpos($_POST["username"], "'") !== false) {
