@@ -78,9 +78,7 @@
 				}
 			}
 
-			$this->output->add_javascript("banshee/".PASSWORD_HASH.".js");
 			$this->output->add_javascript("cms/user.js");
-			$this->output->run_javascript("hash = window['".PASSWORD_HASH."'];");
 
 			$this->output->open_tag("edit");
 
@@ -137,15 +135,10 @@
 		public function execute() {
 			if ($_SERVER["REQUEST_METHOD"] == "POST") {
 				if ($_POST["submit_button"] == "Save user") {
-					/* Fix password
+					/* Generate password
 					 */
 					if (is_true($_POST["generate"])) {
 						$_POST["password"] = random_string(10);
-						$_POST["password_hashed"] = false;
-					}
-					if (is_false($_POST["password_hashed"]) && ($_POST["password"] != "")) {
-						$_POST["plaintext"] = $_POST["password"];
-						$_POST["password"] = hash(PASSWORD_HASH, $_POST["password"].hash(PASSWORD_HASH, $_POST["username"]));
 					}
 
 					/* Save user
