@@ -57,13 +57,8 @@
 			$result["body"] = str_replace("&lt;img src=&quot;/", "&lt;img src=&quot;https://".$hostname."/", $result["body"]);
 			$result["body"] = str_replace("&lt;a href=&quot;/", "&lt;a href=&quot;https://".$hostname."/", $result["body"]);
 
-			$xml = new DomDocument();
-			if ($xml->loadXML($result["body"]) == false) {
-				return;
-			}
-
 			$this->output->start_caching("weblog", 300);
-			$this->output->add_xml($xml, "weblogs");
+			$this->output->add_xml($result["body"], "weblogs");
 			$this->output->stop_caching();
 		}
 
@@ -158,7 +153,7 @@
 			}
 
 			if ($webservers_offline) {
-				$this->output->add_system_message("Warning, one or more webservers are unavailable!");
+				$this->output->add_system_warning("Warning, one or more webservers are unavailable or caused errors during syncing of the statistics!");
 			}
 
 			/* Alerts
