@@ -12,7 +12,7 @@
 			$this->output->add_css("banshee/filter.css");
 
 			$filter = new filter($this->db, $this->output, $this->user);
-			$filter->to_output($this->model->table, false);
+			$filter->to_output($this->model->table, false, false);
 
 			if (($count = $this->model->count_events($filter->webserver, $_SERVER["hide_ss"])) === false) {
 				$this->output->add_tag("result", "Database error.");
