@@ -13,7 +13,7 @@
 				} else if ($_POST["submit_button"] == "Update database") {
 					$this->model->update_database();
 				} else if ($_POST["submit_button"] == "Set password") {
-					$this->model->set_admin_credentials($_POST["username"], $_POST["password"], $_POST["repeat"]);
+					$this->model->set_admin_credentials($_POST);
 				}
 			}
 
@@ -42,10 +42,6 @@
 					ob_clean();
 					break;
                 case "credentials":
-					$this->output->add_javascript("banshee/".PASSWORD_HASH.".js");
-					$this->output->add_javascript("setup.js");
-					$this->output->run_javascript("hash = window['".PASSWORD_HASH."'];");
-
 					if ($_POST["submit_button"] != "Set password") {
 						$_POST["username"] = "admin";
 					}
