@@ -9,14 +9,14 @@
 	/* For internal usage. Only change if you know what you're doing!
 	 */
 	define("BANSHEE_VERSION", "5.0");
-	define("MONITOR_VERSION", "1.5");
+	define("MONITOR_VERSION", "1.6");
 	define("ADMIN_ROLE_ID", 1);
 	define("YES", 1);
 	define("NO", 0);
 	define("USER_STATUS_DISABLED", 0);
 	define("USER_STATUS_CHANGEPWD", 1);
 	define("USER_STATUS_ACTIVE", 2);
-	define("PASSWORD_HASH", "sha256");
+	define("PASSWORD_ITERATIONS", 250000);
 	define("SESSION_NAME", "WebsiteSessionID");
 	define("DAY", 86400);
 	define("PAGE_MODULE", "banshee/page");
@@ -40,12 +40,10 @@
 	 */
 	function banshee_autoload($class_name) {
 		$rename = array(
-			"https"               => "http",
-			"jpeg_image"          => "image",
-			"png_image"           => "image",
-			"gif_image"           => "image",
-			"pop3s"               => "pop3",
-			"banshee_website_ssl" => "banshee_website");
+			"https"      => "http",
+			"jpeg_image" => "image",
+			"png_image"  => "image",
+			"gif_image"  => "image");
 
 		$class_name = strtolower($class_name);
 		if (isset($rename[$class_name])) {
