@@ -29,6 +29,11 @@
 			$this->output = $output;
 			$this->language = $language;
 
+			/* Prevent Cross-Site Request Forgery
+			 */
+			$prevent_csrf = new prevent_CSRF($page, $user, $output);
+			$prevent_csrf->execute();
+
 			$model_class = str_replace("/", "_", $page->module)."_model";
 			if (class_exists($model_class)) {
 				if (is_subclass_of($model_class, "model") == false) {
