@@ -8,14 +8,26 @@
 			$this->db = $db;
 			$this->output= $output;
 			$this->user = $user;
+
+			if (is_array($_SESSION["filter"]) == false) {
+				$_SESSION["filter"] = array(
+					"webserver"       => 0,
+					"hostname"        => 0,
+					"hour_from"       => 0,
+					"hour_to"         => 23);
+			}
 		}
 
 		public function __get($key) {
 			switch ($key) {
 				case "webserver":
-					return is_array($_SESSION["filter"]) ? $_SESSION["filter"]["webserver"] : 0;
+					return $_SESSION["filter"]["webserver"];
 				case "hostname":
-					return is_array($_SESSION["filter"]) ? $_SESSION["filter"]["hostname"] : 0;
+					return $_SESSION["filter"]["hostname"];
+				case "hour_from":
+					return $_SESSION["filter"]["hour_from"];
+				case "hour_to":
+					return $_SESSION["filter"]["hour_to"];
 			}
 
 			return null;
@@ -34,13 +46,7 @@
 			return $result[0]["count"] > 0;
 		}
 
-		public function to_output($table, $show_hostnames = true) {
-			if (is_array($_SESSION["filter"]) == false) {
-				$_SESSION["filter"] = array(
-					"webserver"       => 0,
-					"hostname"        => 0);
-			}
-
+		public function to_output($table, $show_hostnames = true, $show_hours = true) {
 			if ($_SERVER["REQUEST_METHOD"] == "POST") {
 				if (($_POST["submit_button"] == "filter") && $this->valid_webserver($_POST["webserver"])) {
 					if ($_SESSION["filter"]["webserver"] != $_POST["webserver"]) {
@@ -50,6 +56,16 @@
 						$_SESSION["filter"]["hostname"] = $_POST["hostname"];
 					}
 					$_SESSION["filter"]["webserver"] = $_POST["webserver"];
+					if (isset($_POST["hour_from"])) {
+						if ($_POST["hour_from"] <= $_SESSION["filter"]["hour_to"]) {
+							$_SESSION["filter"]["hour_from"] = $_POST["hour_from"];
+						}
+					}
+					if (isset($_POST["hour_to"])) {
+						if ($_POST["hour_to"] >= $_SESSION["filter"]["hour_from"]) {
+							$_SESSION["filter"]["hour_to"] = $_POST["hour_to"];
+						}
+					}
 				}
 			}
 
@@ -110,6 +126,18 @@
 				}
 			}
 
+			/* Hour filter
+			 */
+			if ($show_hours) {
+				$hours = array(
+					"from" => $_SESSION["filter"]["hour_from"],
+					"to"   => $_SESSION["filter"]["hour_to"]);
+				$this->output->open_tag("hours", $hours);
+				for ($h = 0; $h <= 23; $h++) {
+					$this->output->add_tag("hour", $h);
+				}
+				$this->output->close_tag();
+			}
 
 			$this->output->close_tag();
 
