@@ -1,16 +1,15 @@
 <?php
 	abstract class graph_controller extends controller {
 		protected $graphs = array();
-		protected $hostnames = true;
 
 		private function show_graphs() {
 			$filter = new filter($this->db, $this->output, $this->user);
-			$filter->to_output($this->model->table, $this->model->hostnames);
+			$filter->to_output($this->model->table, $this->model->hostnames, $this->model->hours);
 
 			$begin = date("Y-m-d", strtotime("-".(MONITOR_DAYS - 1)." days"));
 			$end = date("Y-m-d");
 
-			if (($statistics = $this->model->get_statistics($begin, $end, $filter->hostname, $filter->webserver)) === false) {
+			if (($statistics = $this->model->get_statistics($begin, $end, $filter)) === false) {
 				$this->output->add_tag("result", "Database error.");
 				return;
 			}
@@ -19,7 +18,7 @@
 				$graph = new graph($this->output);
 				$graph->title = $label;
 				$graph->width = 960;
-				$graph->height = GRAPH_HEIGHT;
+				$graph->height = $this->output->mobile ? GRAPH_HEIGHT_MOBILE : GRAPH_HEIGHT;
 
 				foreach ($statistics as $day => $record) {
 					$timestamp = strtotime($day);
@@ -37,9 +36,9 @@
 
 		private function show_day_information($type, $date) {	
 			$filter = new filter($this->db, $this->output, $this->user);
-			$filter->to_output($this->model->table, $this->model->hostnames);
+			$filter->to_output($this->model->table, $this->model->hostnames, false);
 
-			if (($stats = $this->model->get_day_statistics($type, $date, $filter->hostname, $filter->webserver)) === false) {
+			if (($stats = $this->model->get_day_statistics($type, $date, $filter)) === false) {
 				$this->output->add_tag("result", "Database error.");
 				return false;
 			}
@@ -47,7 +46,7 @@
 			$graph = new graph($this->output);
 			$graph->title = $this->graphs[$type]." for ".date("l j F Y", strtotime($date));
 			$graph->width = 960;
-			$graph->height = GRAPH_HEIGHT;
+			$graph->height = $this->output->mobile ? GRAPH_HEIGHT_MOBILE : GRAPH_HEIGHT;
 
 			foreach ($stats as $hour => $count) {
 				$graph->add_bar("Hour ".$hour, $count, "hour");
@@ -55,14 +54,17 @@
 
 			$graph->to_output();
 
-			if (($stats = $this->model->get_day_information($type, $date, $filter->hostname, $filter->webserver)) === false) {
+			if (($stats = $this->model->get_day_information($type, $date, $filter)) === false) {
 				$this->output->add_tag("result", "Database error.");
 				return false;
 			}
 
 			$this->output->open_tag("day", array(
 				"hostnames" => show_boolean($this->model->hostnames),
-				"label"     => $this->graphs[$type]));
+				"type"      => $type,
+				"label"     => $this->graphs[$type],
+				"yesterday" => date("Y-m-d", strtotime($date." -1 day")),
+				"tomorrow"  => date("Y-m-d", strtotime($date." +1 day"))));
 
 			foreach ($stats as $stat) {
 				if (($type == "requests") || ($type == "bytes_sent")) {
