@@ -271,7 +271,7 @@
 			}
 
 			if ($enable_crypto) {
-				if (stream_socket_enable_crypto($sock, true, STREAM_CRYPTO_METHOD_TLS_CLIENT) == false) {
+				if (stream_socket_enable_crypto($sock, true, STREAM_CRYPTO_METHOD_TLSv1_2_CLIENT) == false) {
 					return false;
 				}
 			}
