@@ -19,63 +19,14 @@
 
 	define("VALIDATE_NONEMPTY",     0);
 
-	/* Abort execution upon dangerous PHP setting
+	/* Secure password with PBKDF2
 	 *
-	 * INPUT:  string key, mixed value
-	 * OUTPUT: -
+	 * INPUT:  string password, string salt
+	 * OUTPUT: string hashed password
 	 * ERROR:  -
 	 */
-	function check_PHP_setting($key, $value) {
-		if (ini_get($key) != $value) {
-			exit("Please, set the PHP flag '".$key."' to '".$value."'!\n");
-		}
-	}
-
-	/* Prevent Cross-Site Request Forgery
-	 * Note that this protection is not 100% safe (browsers that hide this line).
-	 *
-	 * INPUT:  object output, object user
-	 * OUTPUT: -
-	 * ERROR:  -
-	 */
-	function prevent_csrf($output, $user) {
-		if ($_SERVER["REQUEST_METHOD"] != "POST") {
-			return false;
-		}
-
-		if (isset($_SERVER["HTTP_ORIGIN"]) != false) {
-			$referer = $_SERVER["HTTP_ORIGIN"];
-		} else if (isset($_SERVER["HTTP_REFERER"]) != false) {
-			$referer = $_SERVER["HTTP_REFERER"];
-		} else {
-			if ($_SESSION["csrf_warning_shown"] == false) {
-				$output->add_system_warning("Your browser hides the referrer HTTP header line. You are therefor vulnerable for CSRF attacks via this website!");
-				$_SESSION["csrf_warning_shown"] = true;
-			}
-			return false;
-		}
-
-		list($protocol,, $referer_host) = explode("/", $referer, 4);
-		list($referer_host) = explode(":", $referer_host);
-		if (($protocol != "http:") && ($protocol != "https:")) {
-			return false;
-		}
-
-		list($http_host) = explode(":", $_SERVER["HTTP_HOST"]);
-		if ($http_host == $referer_host) {
-			return false;
-		}   
-
-		$message = sprintf("CSRF attempt from %s blocked", $_SERVER["HTTP_REFERER"]);
-
-		$output->add_system_warning($message);
-		$user->log_action($message);
-		$user->logout();
-		$_SERVER["REQUEST_METHOD"] = "GET";
-		$_GET = array();
-		$_POST = array();
-
-		return true;
+	function hash_password($password, $salt) {
+		return hash_pbkdf2("sha256", $password, hash("sha256", $salt), PASSWORD_ITERATIONS, 0);
 	}
 
 	/* Validate input
