@@ -113,17 +113,15 @@
 			$_SESSION["last_private_visit"] = time();
 
 			$this->session->set_user_id($user_id);
-
-			unset($_SESSION["challenge"]);
 		}
 
 		/* Verify user credentials
 		 *
-		 * INPUT:  string username, string password, boolean challenge-response method used
+		 * INPUT:  string username, string password
 		 * OUTPUT: boolean login correct
 		 * ERROR:  -
 		 */
-		public function login_password($username, $password, $use_challenge_response_method) {
+		public function login_password($username, $password) {
 			$query = "select * from users where username=%s and status!=%d limit 1";
 			if (($data = $this->db->execute($query, $username, USER_STATUS_DISABLED)) == false) {
 				header("X-Hiawatha-Monitor: failed_login");
@@ -134,14 +132,8 @@
 
 			usleep(rand(0, 10000));
 
-			if ($use_challenge_response_method) {
-				if (hash(PASSWORD_HASH, $_SESSION["challenge"].$user["password"]) === $password) {
-					$this->login((int)$user["id"]);
-				}
-			} else {
-				if ($user["password"] === hash(PASSWORD_HASH, $password.hash(PASSWORD_HASH, $username))) {
-					$this->login((int)$user["id"]);
-				}
+			if ($user["password"] === hash_password($password, $username)) {
+				$this->login((int)$user["id"]);
 			}
 
 			if ($this->logged_in == false) {
@@ -249,7 +241,9 @@
 
 			/* No roles, no access
 			 */
-			if (count($this->record["role_ids"]) == 0) {
+			if (is_array($this->record["role_ids"]) == false) {
+				return false;
+			} else if (count($this->record["role_ids"]) == 0) {
 				return false;
 			}
 
