@@ -7,7 +7,7 @@
 		public function get_users() {
 			$query = "select * from users where id!=%d and status!=%d order by username";
 
-			return $this->db->execute($query, $this->user->id, STATUS_DISABLED);
+			return $this->db->execute($query, $this->user->id, USER_STATUS_DISABLED);
 		}
 	}
 ?>
