@@ -77,9 +77,9 @@
 				}
 
 				if ($new["median"] == 0) {
-					$new["change"] = $new["today"] * 100;
+					$new["change"] = $new["today"];
 				} else {
-					$new["change"] = round(($new["today"] - $new["median"]) / $new["median"]) * 100;
+					$new["change"] = round(($new["today"] - $new["median"]) / $new["median"], 1);
 				}
 
 				if (($new["today"] >= $this->settings->dashboard_threshold_value) && ($new["change"] >= $this->settings->dashboard_threshold_change)) {
