@@ -21,7 +21,7 @@
 		public function update_session($session) {
 			$query = "update sessions set name=%s where id=%d and user_id=%d";
 
-			return $this->db->execute($query, $session["name"], $session["id"], $this->user->id);
+			return $this->db->execute($query, $session["name"], $session["id"], $this->user->id) !== false;
 		}
 
 		public function delete_session($id) {
