@@ -13,12 +13,6 @@
 	require("../libraries/banshee.php");
 	require("../libraries/security.php");
 
-	/* Abort on dangerous PHP settings
-	 */
-	check_PHP_setting("allow_url_include", 0);
-	check_PHP_setting("magic_quotes_gpc", 0);
-	check_PHP_setting("register_globals", 0);
-
 	/* Create core objects
 	 */
 	$_database = new MySQLi_connection(DB_HOSTNAME, DB_DATABASE, DB_USERNAME, DB_PASSWORD);
@@ -38,10 +32,6 @@
 		$logging->execute();
 	}
 
-	/* Prevent Cross-Site Request Forgery
-	 */
-	prevent_csrf($_output, $_user);
-
 	/* User switch warning
 	 */
 	if (isset($_SESSION["user_switch"])) {
@@ -138,18 +128,7 @@
 			print "Controller class '".$controller_class."' does not extend 'controller'.\n";
 		} else {
 			$_controller = new $controller_class($_database, $_settings, $_user, $_page, $_output, $_language);
-			$method = "execute";
-
-			if (is_true(URL_PARAMETERS)) {
-				$reflection = new reflectionobject($_controller);
-				$param_count = count($reflection->getmethod($method)->getParameters());
-				unset($reflection);
-
-				$params = array_pad($_page->parameters, $param_count, null);
-				call_user_func_array(array($_controller, $method), $params);
-			} else {
-				$_controller->$method();
-			}
+			$_controller->execute();
 			unset($_controller);
 
 			if ($_output->disabled) {
