@@ -40,7 +40,7 @@ function get_alerts() {
 			if (done++ == max_alert_count) {
 				$('img.loading').remove();
 				if (alerts == 0) {
-					$('div.alerts').append('There are no alerts at this moment.');
+					$('div.alerts').append('<p>There are no alerts at this moment.</p>');
 				}
 
 				if (page_refresh > 0) {
